pub struct Task {
pub id: String,
pub context_id: String,
pub status: Option<TaskStatus>,
pub artifacts: Vec<Artifact>,
pub history: Vec<Message>,
pub metadata: Option<Struct>,
}Expand description
Task is the core unit of action for A2A. It has a current status
and when results are created for the task they are stored in the
artifact. If there are multiple turns for a task, these are stored in
history.
Fields
id: StringUnique identifier (e.g. UUID) for the task, generated by the server for a new task.
context_id: StringUnique identifier (e.g. UUID) for the contextual collection of interactions (tasks and messages).
status: Option<TaskStatus>The current status of a Task, including state and a message.
artifacts: Vec<Artifact>A set of output artifacts for a Task.
history: Vec<Message>protolint:disable REPEATED_FIELD_NAMES_PLURALIZED
The history of interactions from a Task.
metadata: Option<Struct>protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store custom metadata about a task.